@@ -600,26 +600,51 @@ padding <- function(x, i = NULL, j = NULL, padding = NULL,
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
-#' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
-#' @param align text alignment - a single character value, expected value
-#' is one of 'left', 'right', 'center', 'justify'.
+#' @param part partname of the table (one of 'body', 'header', 'footer', 'all')
+#' @param align text alignment - a single character value, or a vector of
+#' character values equal in length to the number of columns selected by `j`.
+#' Expected values must be from the set of ('left', 'right', 'center', or 'justify').
+#'
+#' If the number of columns is a multiple of the length of the `align` parameter,
+#' then the values in `align` will be recycled across the remaining columns.
 #' @family sugar functions for table style
 #' @examples
-#' ft <- flextable(head(mtcars)[, 3:6])
-#' ft <- align(ft, align = "right", part = "all")
-#' ft <- theme_tron_legacy(ft)
-#' ft
-align <- function(x, i = NULL, j = NULL, align = c("left", "center", "right", "justify"),
-                  part = "body") {
+#' # Table of 6 columns
+#' ft_car <- flextable(head(mtcars)[, 2:7])
+#'
+#' # All 6 columns right aligned
+#' align(ft_car, align = "right", part = "all")
+#'
+#' # Manually specify alignment of each column
+#' align(
+#'   ft_car,
+#'   align = c("left", "right", "left", "center", "center", "right"),
+#'   part = "all")
+#'
+#' # Center-align column 2 and left-align column 5
+#' align(ft_car, j = c(2, 5), align = c("center", "left"), part = "all")
+#'
+#' # Alternate left and center alignment across columns 1-4 for header only
+#' align(ft_car, j = 1:4, align = c("left", "center"), part = "header")
+align <- function(x, i = NULL, j = NULL, align = "left", part = c("body", "header", "footer", "all")) {
   if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "align()"))
   }
-  part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
-  align_value <- match.arg(align, several.ok = TRUE)
+  part <- match.arg(part, c("body", "header", "footer", "all"), several.ok = FALSE)
+
+  allowed_alignments <- c("left", "center", "right", "justify")
+  if (!all(align %in% allowed_alignments)) {
+    stop(
+      "Invalid `align` argument(s) provided to `align()`: \"",
+      paste(setdiff(align, allowed_alignments), collapse = "\", \""),
+      "\".\n  `align` should be one of: \"", paste(allowed_alignments, collapse = "\", \""),
+      "\"."
+    )
+  }
 
   if (part == "all") {
     for (p in c("header", "body", "footer")) {
-      x <- align(x = x, i = i, j = j, align = align_value, part = p)
+      x <- align(x = x, i = i, j = j, align = align, part = p)
     }
     return(x)
   }
@@ -632,8 +657,8 @@ align <- function(x, i = NULL, j = NULL, align = c("left", "center", "right", "j
   i <- get_rows_id(x[[part]], i)
   j <- get_columns_id(x[[part]], j)
 
-  if (length(align_value) == length(j)) {
-    align_value <- rep(align_value, each = length(i))
+  if (length(j) %% length(align) == 0) {
+    align <- rep(align, each = length(i))
   }
 
   x[[part]]$styles$pars <- set_par_struct_values(
@@ -641,7 +666,7 @@ align <- function(x, i = NULL, j = NULL, align = c("left", "center", "right", "j
     i = i,
     j = j,
     property = "text.align",
-    value = align_value
+    value = align
   )
   x
 }
@@ -728,9 +753,9 @@ keep_with_next <- function(x, i = NULL, value = TRUE, part = "body") {
 #'   fp_tab(pos = 1.4, style = "decimal")
 #' )
 #'
-#' zz <- flextable(z) |>
-#'   tab_settings(j = 2, value = ts) |>
-#'   width(width = c(1.5, 2))
+#' zz <- flextable(z)
+#' zz <- tab_settings(zz, j = 2, value = ts)
+#' zz <- width(zz, width = c(1.5, 2))
 #'
 #'
 #' save_as_docx(zz, path = tempfile(fileext = ".docx"))
@@ -739,7 +764,7 @@ tab_settings <- function(x, i = NULL, j = NULL, value = TRUE, part = "body") {
 
   if (part == "all") {
     for (p in c("header", "body", "footer")) {
-      x <- tab_settings(x = x, i = i, value = value, part = p)
+      x <- tab_settings(x = x, i = i, j = j, value = value, part = p)
     }
     return(x)
   }
@@ -754,7 +779,7 @@ tab_settings <- function(x, i = NULL, j = NULL, value = TRUE, part = "body") {
   x[[part]]$styles$pars <- set_par_struct_values(
     x = x[[part]]$styles$pars,
     i = i,
-    j = NULL,
+    j = j,
     property = "tabs",
     value = as.character(value)
   )
